diff --git a/src/Persistence/Initialization/Updates/FinishElfMasterTreePlugIn.cs b/src/Persistence/Initialization/Updates/FinishElfMasterTreePlugIn.cs
index 6424ac0..1d4e294 100644
--- a/src/Persistence/Initialization/Updates/FinishElfMasterTreePlugIn.cs
+++ b/src/Persistence/Initialization/Updates/FinishElfMasterTreePlugIn.cs
@@ -15,7 +15,7 @@ using MUnique.OpenMU.Persistence.Initialization.Skills;
using MUnique.OpenMU.PlugIns;
///
/// This update completes the elf master tree and fixes some of its skill values.
///
[PlugIn]
[Display(Name = PlugInName, Description = PlugInDescription)]
@@ -30,7 +30,7 @@ public class FinishElfMasterTreePlugIn : UpdatePlugInBase
///
/// The plug in description.
///
- internal const string PlugInDescription = "This update completes the elf master tree and fixes some of its skill values.";
+ internal const string PlugInDescription = "This update completes the elf master tree and fixes some of its skill values. It also adds the missing extra projectile (4th) on some higher level (cross)bows.";
///
public override UpdateVersion Version => UpdateVersion.FinishElfMasterTree;
@@ -15,7 +15,7 @@ using MUnique.OpenMU.Persistence.Initialization.Skills;
using MUnique.OpenMU.PlugIns;
///
-/// This update completes the elf master tree and fixes some of its skill values.
+/// This update completes the elf master tree and fixes some of its skill values. It also adds the missing extra projectile (4th) on some higher level (cross)bows.
///
[PlugIn]